@@ -11,6 +11,7 @@
 #include "ntp_malloc.h"
 #include "ntp_assert.h"
 #include "ntp_control.h"
+#include "lib_strbuf.h"
 
 /*
  * Maximum number of arguments
@@ -57,12 +58,16 @@
 #define	NTP_INT		0x3	/* signed integer */
 #define	NTP_ADD		0x4	/* IP network address */
 #define IP_VERSION	0x5	/* IP version */
+#define	NTP_ADP		0x6	/* IP address and port */
+#define NTP_LFP		0x7	/* NTP timestamp */
+#define NTP_MODE	0x8	/* peer mode */
+#define NTP_2BIT	0x9	/* leap bits */
 
 /*
  * Arguments are returned in a union
  */
 typedef union {
-	char *string;
+	const char *string;
 	long ival;
 	u_long uval;
 	sockaddr_u netnum;
@@ -74,7 +79,7 @@ typedef union {
 struct parse {
 	const char *keyword;
 	arg_v argval[MAXARGS];
-	int nargs;
+	size_t nargs;
 };
 
 /*
@@ -98,35 +103,52 @@ struct association {
 	u_short status;
 };
 
-#define	MAXASSOC	1024
+/*
+ * mrulist terminal status interval
+ */
+#define	MRU_REPORT_SECS	5
 
 /*
- * Structure for translation tables between text format
- * variable indices and text format.
+ * var_format is used to override cooked formatting for selected vars.
  */
-struct ctl_var {
-	u_short code;
-	u_short fmt;
-	const char *text;
+typedef struct var_format_tag {
+	const char *	varname;
+	u_short		fmt;
+} var_format;
+
+typedef struct chost_tag chost;
+struct chost_tag {
+	const char *name;
+	int 	    fam;
 };
 
+extern chost	chosts[];
+
 extern int	interactive;	/* are we prompting? */
 extern int	old_rv;		/* use old rv behavior? --old-rv */
+extern u_int	assoc_cache_slots;/* count of allocated array entries */
+extern u_int	numassoc;	/* number of cached associations */
+extern u_int	numhosts;
 
+extern	void	grow_assoc_cache(void);
 extern	void	asciize		(int, char *, FILE *);
 extern	int	getnetnum	(const char *, sockaddr_u *, char *, int);
 extern	void	sortassoc	(void);
 extern	void	show_error_msg	(int, associd_t);
-extern	int	doquery		(int, associd_t, int, int, char *,
-				 u_short *, int *, const char **);
-extern	int	doqueryex	(int, associd_t, int, int, char *,
-				 u_short *, int *, const char **, int);
-extern	char *	nntohost	(sockaddr_u *);
+extern	int	dogetassoc	(FILE *);
+extern	int	doquery		(int, associd_t, int, size_t, const char *,
+				 u_short *, size_t *, const char **);
+extern	int	doqueryex	(int, associd_t, int, size_t, const char *,
+				 u_short *, size_t *, const char **, int);
+extern	const char * nntohost	(sockaddr_u *);
+extern	const char * nntohost_col (sockaddr_u *, size_t, int);
+extern	const char * nntohostp	(sockaddr_u *);
 extern	int	decodets	(char *, l_fp *);
 extern	int	decodeuint	(char *, u_long *);
-extern	int	nextvar		(int *, const char **, char **, char **);
+extern	int	nextvar		(size_t *, const char **, char **, char **);
 extern	int	decodetime	(char *, l_fp *);
-extern	void	printvars	(int, const char *, int, int, int, FILE *);
+extern	void	printvars	(size_t, const char *, int, int, int, FILE *);
 extern	int	decodeint	(char *, long *);
-extern	int	findvar		(char *, struct ctl_var *, int code);
-extern	void	makeascii	(int, const char *, FILE *);
+extern	void	makeascii	(size_t, const char *, FILE *);
+extern	const char * trunc_left	(const char *, size_t);
+extern	const char * trunc_right(const char *, size_t);
